==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/StringMatchPrefixFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StringMatchPrefixFluent<A extends StringMatchPrefixFluent<A>> extends BaseFluent<A>{
  public StringMatchPrefixFluent() {
  }
  public StringMatchPrefixFluent(StringMatchPrefix instance) {
    instance = (instance != null ? instance : new StringMatchPrefix());

    if (instance != null) {
      this.withPrefix(instance.getPrefix());
      this.withPrefix(instance.getPrefix());
    }
  }
  private String prefix;
  public String getPrefix() {
    return this.prefix;
  }
  public A withPrefix(String prefix) {
    this.prefix=prefix; return (A) this;
  }
  public boolean hasPrefix() {
    return this.prefix != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchPrefixFluent that = (StringMatchPrefixFluent) o;
    if (!java.util.Objects.equals(prefix, that.prefix)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(prefix,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (prefix != null) { sb.append("prefix:"); sb.append(prefix); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/StringMatchPrefixFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StringMatchPrefixFluent<A extends StringMatchPrefixFluent<A>> extends BaseFluent<A>{
  public StringMatchPrefixFluent() {
  }
  
  public StringMatchPrefixFluent(StringMatchPrefix instance) {
    this.copyInstance(instance);
  }
  private String prefix;
  
  protected void copyInstance(StringMatchPrefix instance) {
    instance = (instance != null ? instance : new StringMatchPrefix());
  
    if (instance != null) {
        this.withPrefix(instance.getPrefix());
        this.withPrefix(instance.getPrefix());
      }
  }
  
  public String getPrefix() {
    return this.prefix;
  }
  
  public A withPrefix(String prefix) {
    this.prefix=prefix; return (A) this;
  }
  
  public boolean hasPrefix() {
    return this.prefix != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchPrefixFluent that = (StringMatchPrefixFluent) o;
    if (!java.util.Objects.equals(prefix, that.prefix)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(prefix,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (prefix != null) { sb.append("prefix:"); sb.append(prefix); }
    sb.append("}");
    return sb.toString();
  }
  

}
